########
PyNuance
########

|docs| |codeclimate| |build| |pypi|

PyNuance is a wrapper for Nuance Communications services

Documentation
#############

http://pynuance.readthedocs.io/en/latest/

DISCLAMER
#########

This code is Apache V2. See LICENSE.txt file attached.

WARNING
#######

* This library is not related with Nuance Communications.
* It's not made or supported by Nuance Communications.
* I'm not employed by Nuance Communications.


.. |docs| image:: https://readthedocs.org/projects/pynuance/badge/?version=latest
    :alt: Documentation Status
    :scale: 100%
    :target: http://pynuance.readthedocs.io/en/latest/

.. |build| image:: https://circleci.com/gh/titilambert/pynuance/tree/master.svg?style=svg
    :target: https://circleci.com/gh/titilambert/pynuance/tree/master

.. |codeclimate| image:: https://codeclimate.com/github/titilambert/pynuance/badges/gpa.svg
    :target: https://codeclimate.com/github/titilambert/pynuance
    :alt: Code Climate

.. |pypi| image:: https://badge.fury.io/py/pynuance.svg
    :target: https://badge.fury.io/py/pynuance
